@@ -276,7 +276,16 @@ public:
     void visitCatchItem(CatchItemAst *node) override
     {
         printToken(node, QStringLiteral("catchItem"));
-        if (node->catchClass) printToken(node->catchClass, QStringLiteral("namespacedIdentifier"), QStringLiteral("catchClass"));
+        if (node->catchClassSequence)
+        {
+            const KDevPG::ListNode<NamespacedIdentifierAst*> *__it = node->catchClassSequence->front(), *__end = __it;
+            do
+            {
+                printToken(__it->element, QStringLiteral("namespacedIdentifier"), QStringLiteral("catchClass[]"));
+                __it = __it->next;
+            }
+            while (__it != __end);
+        }
         if (node->var) printToken(node->var, QStringLiteral("variableIdentifier"), QStringLiteral("var"));
         if (node->statements) printToken(node->statements, QStringLiteral("innerStatementList"), QStringLiteral("statements"));
         ++m_indent;
